@@ -1,4 +1,4 @@
-/* $Id: menulabels.c,v 1.7 2004/09/12 16:49:48 stpohle Exp $
+/* $Id: menulabels.c,v 1.8 2006-02-06 21:18:01 stpohle Exp $
  * Menuhandling: labels */
 
 #include "basic.h"
@@ -72,7 +72,7 @@ void menu_create_text (_menu *menu, char *name, int x, int y, int maxlen, int ma
 	memset (text, 0, sizeof (text));
 	memset (out, 0, sizeof (out));
 	va_start (args, fmt);
-	vsprintf (text, fmt, args);
+	vsnprintf (text, 1024, fmt, args);
 	va_end (args);
 
 	menu_formattext (text, out, lineptr, &linecnt, &maxchar, maxlen, maxlines);
