@@ -1,4 +1,4 @@
-/* $Id: multiwait.c,v 1.58 2006/08/08 20:04:19 stpohle Exp $
+/* $Id: multiwait.c,v 1.60 2008-07-27 11:24:37 stpohle Exp $
    multiwait.c - this manages only the network screen where
    everyone have to select it's players and where even the basic chat is inside
 */
@@ -85,6 +85,11 @@ static void mw_keys_loop () {
         bman.updatestatusbar = 1; // force an update
     }
 
+    if (GT_MP_PTPM && mw_check_players () < 2 && keyb_gamekeys.state[BCK_pause] && !keyb_gamekeys.old[BCK_pause]) {
+		font_gfxdraw (20,20,"There are not enough configured players", 0, COLOR_brown, 0x1000);
+		font_gfxdraw (20,40,"(each player needs to press Ctrl to select the role)", 0, COLOR_brown, 0x1000);
+    }
+
 	if (keyb_gamekeys.state[BCK_fullscreen]  && !keyb_gamekeys.old[BCK_fullscreen]) {
         /* Switch Fullscreen */
 		SDL_WM_ToggleFullScreen(gfx.screen);
@@ -99,15 +104,15 @@ static void mw_keys_loop () {
         bman.state = GS_startup;
     }
 
-	if ((keyb_gamekeys.state[BCPK_drop] && !keyb_gamekeys.old[BCPK_drop])
-		|| ((!IS_LPLAYER2) && keyb_gamekeys.state[BCPK_max + BCPK_drop] && !keyb_gamekeys.old[BCPK_max + BCPK_drop])) {
+	if (((IS_LPLAYER2) && keyb_gamekeys.state[BCPK_max + BCPK_drop] && !keyb_gamekeys.old[BCPK_max + BCPK_drop])
+		|| ((!IS_LPLAYER2) && keyb_gamekeys.state[BCPK_drop] && !keyb_gamekeys.old[BCPK_drop])) {
 		/* player 1 want to select a new gfx */
 		playermenu_selgfx (bman.p_nr);
 		bman.updatestatusbar = 1;
 		keyb_loop (NULL);	// to reload the current keys
 	}
 
-	if (IS_LPLAYER2 && keyb_gamekeys.state[BCPK_max + BCPK_drop] && !keyb_gamekeys.old[BCPK_max + BCPK_drop]) {
+	if (IS_LPLAYER2 && keyb_gamekeys.state[BCPK_max + BCPK_max + BCPK_drop] && !keyb_gamekeys.old[BCPK_max + BCPK_max + BCPK_drop]) {
 		/* player 2 want to select a new gfx */
 		playermenu_selgfx (bman.p2_nr);
 		bman.updatestatusbar = 1;
